# Config.pm -- RoBlog
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2.1 of the License, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
# more details.
# 
# You should have received a copy of the GNU Library General Public License
# along with this library; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
#
package RoBlog::Config;

use Exporter;
@ISA = qw(Exporter);
@EXPORT = qw($dbi_uri $db_user $db_pass
			 $noauth_ips $blog_pwd $comment_cookie
			 $protocol $hostname $basepath $baseurl $blogtitle $lang
			 $items_per_page $feed_items $max_search $logging
			 @pingurls);
no warnings 'redefine';

# ----------------------------------------------------------------------------
# user configuration starts here:

# connect string for DBI, giving db name, host and port
$dbi_uri = "dbi:Pg:dbname=blog;host=DBHOST;port=5432";
# DB user and its password
$db_user = "DBUSER";
$db_pass = "DBPASS";

# IP ranges (CIDR notation) allowed to access Atom API without WSSE
# UsernameToken authentication
$noauth_ips = [qw(127.0.0.1/32 ::1/128)];
# password for WSSE authentication
$blog_pwd  = "SECRET";
# some random string unique for this site, used as salt for comment auth
$comment_cookie = "1234567890abcdefhgij";

# protocol (http or https)
$protocol = "http";
# hostname where RoBlog lives
$hostname = "www";
# base path where to access RoBlog
$basepath = "/PATH";
# name of blog
$blogtitle = "SMART TITLE";
# language code
$lang = "de-DE";

# how many items to list on index pages
$items_per_page = 20;
# how many items to deliver via Atom feed
$feed_items = 15;
# max. search results to display
$max_search = 30;
# report posts, edits, ping results, pingback results, and received pingbacks
# in Apache log file (prio notice)
$logging = 0;

# URL to send weblog.com type pings after updates
@pingurls = qw(http://rpc.weblogs.com/RPC2
			   http://ping.blo.gs/
			   http://rpc.technorati.com/rpc/ping);

# ----------------------------------------------------------------------------
# derived:

$baseurl = "$protocol://$hostname$basepath";

1;
